PluggableWithAnywhereDoor class abstract

Inheritance

Constructors

PluggableWithAnywhereDoor()

Properties

displayName → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
iconImageProvider → ImageProvider<Object>
no setterinherited
name → String
no setterinherited
no setter
route → Route?
no setter
routeNameAndArgs → Tuple2<String, Object?>?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildWidget(BuildContext? context) → Widget?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTrigger() → void
inherited
popResultReceive(dynamic result) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited